@@ -483,6 +483,9 @@ SERVICE_VERSIONS = {
     "tcr": [
         "2019-09-24"
     ],
+    "tcss": [
+        "2020-11-01"
+    ],
     "tdid": [
         "2021-05-19"
     ],
